// -*- C++ -*-
//
//  This file is part of Siena, a wide-area event notification system.
//  See http://www.cs.colorado.edu/serl/siena/
//
//  Authors: See the file AUTHORS for full details.
//
//  Copyright (C) 2002-2004 University of Colorado
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to serl@cs.colorado.edu.
//
// $Id: large.cc,v 1.1 2006-01-14 06:19:47 rutherfo Exp $
//
#include <cassert>
#include <iostream>
#include <vector>
#include "siena/simplify.h"
#include "siena/ssimp_types.h"

using namespace siena;
using namespace std;

int main( int argc, char** argv )
{
  SimplifyingPredicate sPred;
  BasicPredicate bPred;

  /*
  ** The following filters and constraints were created by greping
  ** "Barhop" out of the siena workload file: I100_F50_C4_1
  */

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "peat"));
    f.add(Constraint(string("Rawlings"), pf_id, "portfolio"));
    f.add(Constraint(string("baptizing"), gt_id, "sponge"));
    f.add(Constraint(string("grandness"), eq_id, 87.1000));
    f.add(Constraint(string("paralyzes"), eq_id, "Smithsonian"));
    f.add(Constraint(string("texts"), gt_id, 52.1000));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "peat"));
    f.add(Constraint(string("Rawlings"), pf_id, "portfolio"));
    f.add(Constraint(string("baptizing"), gt_id, "sponge"));
    f.add(Constraint(string("grandness"), eq_id, 87.1000));
    f.add(Constraint(string("paralyzes"), eq_id, "Smithsonian"));
    f.add(Constraint(string("texts"), gt_id, 52.1000));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("lemmings"), eq_id, "segregated"));
    f.add(Constraint(string("microcoded"), eq_id, true));
    f.add(Constraint(string("mung"), lt_id, "grievously"));
    f.add(Constraint(string("retractions"), eq_id, 82.1000));
    f.add(Constraint(string("symposia"), eq_id, (int_t)63));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("lemmings"), eq_id, "segregated"));
    f.add(Constraint(string("microcoded"), eq_id, true));
    f.add(Constraint(string("mung"), lt_id, "grievously"));
    f.add(Constraint(string("retractions"), eq_id, 82.1000));
    f.add(Constraint(string("symposia"), eq_id, (int_t)63));
    bPred.add(f);
  }
  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)0));
    f.add(Constraint(string("squeaked"), eq_id, "preparative"));
    f.add(Constraint(string("unintentionally"), eq_id, (int_t)15));
    sPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)52));
    f.add(Constraint(string("Leone"), lt_id, 94.1000));
    f.add(Constraint(string("heckle"), eq_id, (int_t)76));
    f.add(Constraint(string("retractions"), eq_id, 78.1000));
    f.add(Constraint(string("tomography"), eq_id, false));
    f.add(Constraint(string("victimized"), eq_id, (int_t)0));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)52));
    f.add(Constraint(string("Leone"), lt_id, 94.1000));
    f.add(Constraint(string("heckle"), eq_id, (int_t)76));
    f.add(Constraint(string("retractions"), eq_id, 78.1000));
    f.add(Constraint(string("tomography"), eq_id, false));
    f.add(Constraint(string("victimized"), eq_id, (int_t)0));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, "productive"));
    f.add(Constraint(string("Colombians"), eq_id, (int_t)17));
    f.add(Constraint(string("freight"), gt_id, (int_t)10));
    f.add(Constraint(string("league"), pf_id, "send"));
    f.add(Constraint(string("moron"), lt_id, "culpable"));
    f.add(Constraint(string("retractions"), eq_id, (int_t)89));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, "productive"));
    f.add(Constraint(string("Colombians"), eq_id, (int_t)17));
    f.add(Constraint(string("freight"), gt_id, (int_t)10));
    f.add(Constraint(string("league"), pf_id, "send"));
    f.add(Constraint(string("moron"), lt_id, "culpable"));
    f.add(Constraint(string("retractions"), eq_id, (int_t)89));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, "preassigning"));
    f.add(Constraint(string("Palestine"), eq_id, "Luzon"));
    f.add(Constraint(string("cottonwood"), gt_id, 59.1000));
    f.add(Constraint(string("freights"), eq_id, 92.1000));
    f.add(Constraint(string("mergers"), eq_id, 94.1000));
    f.add(Constraint(string("retractions"), ss_id, "entertain"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, "preassigning"));
    f.add(Constraint(string("Palestine"), eq_id, "Luzon"));
    f.add(Constraint(string("cottonwood"), gt_id, 59.1000));
    f.add(Constraint(string("freights"), eq_id, 92.1000));
    f.add(Constraint(string("mergers"), eq_id, 94.1000));
    f.add(Constraint(string("retractions"), ss_id, "entertain"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, true));
    f.add(Constraint(string("Colombians"), lt_id, "piercing"));
    f.add(Constraint(string("graces"), eq_id, (int_t)58));
    f.add(Constraint(string("ravening"), pf_id, "crystallizing"));
    f.add(Constraint(string("stereos"), eq_id, false));
    f.add(Constraint(string("victimized"), eq_id, (int_t)96));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, true));
    f.add(Constraint(string("Colombians"), lt_id, "piercing"));
    f.add(Constraint(string("graces"), eq_id, (int_t)58));
    f.add(Constraint(string("ravening"), pf_id, "crystallizing"));
    f.add(Constraint(string("stereos"), eq_id, false));
    f.add(Constraint(string("victimized"), eq_id, (int_t)96));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "employs"));
    f.add(Constraint(string("braziers"), lt_id, (int_t)12));
    f.add(Constraint(string("refuses"), eq_id, (int_t)36));
    f.add(Constraint(string("retractions"), eq_id, true));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "employs"));
    f.add(Constraint(string("braziers"), lt_id, (int_t)12));
    f.add(Constraint(string("refuses"), eq_id, (int_t)36));
    f.add(Constraint(string("retractions"), eq_id, true));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)48));
    f.add(Constraint(string("blending"), eq_id, 47.1000));
    f.add(Constraint(string("settable"), eq_id, "recapturing"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)48));
    f.add(Constraint(string("blending"), eq_id, 47.1000));
    f.add(Constraint(string("settable"), eq_id, "recapturing"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)40));
    f.add(Constraint(string("aback"), eq_id, (int_t)99));
    f.add(Constraint(string("metaphors"), gt_id, (int_t)32));
    f.add(Constraint(string("moron"), eq_id, "bursitis"));
    f.add(Constraint(string("retractions"), eq_id, "metacircularity"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)40));
    f.add(Constraint(string("aback"), eq_id, (int_t)99));
    f.add(Constraint(string("metaphors"), gt_id, (int_t)32));
    f.add(Constraint(string("moron"), eq_id, "bursitis"));
    f.add(Constraint(string("retractions"), eq_id, "metacircularity"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)34));
    f.add(Constraint(string("Canadianization"), eq_id, "necessitated"));
    f.add(Constraint(string("Colombians"), eq_id, "anonymously"));
    f.add(Constraint(string("exiled"), pf_id, "criticism"));
    f.add(Constraint(string("league"), pf_id, "dealer"));
    f.add(Constraint(string("tomography"), sf_id, "watcher"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)34));
    f.add(Constraint(string("Canadianization"), eq_id, "necessitated"));
    f.add(Constraint(string("Colombians"), eq_id, "anonymously"));
    f.add(Constraint(string("exiled"), pf_id, "criticism"));
    f.add(Constraint(string("league"), pf_id, "dealer"));
    f.add(Constraint(string("tomography"), sf_id, "watcher"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)9));
    f.add(Constraint(string("Colombians"), gt_id, "shopped"));
    f.add(Constraint(string("access"), ss_id, "doubted"));
    f.add(Constraint(string("tomography"), eq_id, "veil"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)9));
    f.add(Constraint(string("Colombians"), gt_id, "shopped"));
    f.add(Constraint(string("access"), ss_id, "doubted"));
    f.add(Constraint(string("tomography"), eq_id, "veil"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)60));
    f.add(Constraint(string("recode"), eq_id, (int_t)84));
    f.add(Constraint(string("retractions"), eq_id, (int_t)33));
    f.add(Constraint(string("truncated"), eq_id, 83.1000));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)60));
    f.add(Constraint(string("recode"), eq_id, (int_t)84));
    f.add(Constraint(string("retractions"), eq_id, (int_t)33));
    f.add(Constraint(string("truncated"), eq_id, 83.1000));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)75));
    f.add(Constraint(string("access"), ss_id, "inventories"));
    f.add(Constraint(string("baptizing"), lt_id, (int_t)81));
    f.add(Constraint(string("retractions"), eq_id, true));
    f.add(Constraint(string("televised"), lt_id, "curlers"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)75));
    f.add(Constraint(string("access"), ss_id, "inventories"));
    f.add(Constraint(string("baptizing"), lt_id, (int_t)81));
    f.add(Constraint(string("retractions"), eq_id, true));
    f.add(Constraint(string("televised"), lt_id, "curlers"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, 26.1000));
    f.add(Constraint(string("Colombians"), lt_id, "extended"));
    f.add(Constraint(string("breech"), eq_id, (int_t)82));
    f.add(Constraint(string("mergers"), eq_id, (int_t)0));
    f.add(Constraint(string("retractions"), eq_id, (int_t)81));
    f.add(Constraint(string("settable"), eq_id, (int_t)74));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, 26.1000));
    f.add(Constraint(string("Colombians"), lt_id, "extended"));
    f.add(Constraint(string("breech"), eq_id, (int_t)82));
    f.add(Constraint(string("mergers"), eq_id, (int_t)0));
    f.add(Constraint(string("retractions"), eq_id, (int_t)81));
    f.add(Constraint(string("settable"), eq_id, (int_t)74));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)74));
    f.add(Constraint(string("Colombians"), lt_id, (int_t)83));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)74));
    f.add(Constraint(string("Colombians"), lt_id, (int_t)83));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)7));
    f.add(Constraint(string("dejected"), lt_id, (int_t)72));
    f.add(Constraint(string("moron"), gt_id, (int_t)11));
    f.add(Constraint(string("rectangles"), lt_id, (int_t)84));
    f.add(Constraint(string("victimized"), gt_id, 14.1000));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)7));
    f.add(Constraint(string("dejected"), lt_id, (int_t)72));
    f.add(Constraint(string("moron"), gt_id, (int_t)11));
    f.add(Constraint(string("rectangles"), lt_id, (int_t)84));
    f.add(Constraint(string("victimized"), gt_id, 14.1000));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)88));
    f.add(Constraint(string("Finnegan"), eq_id, true));
    f.add(Constraint(string("mature"), eq_id, "multiplicatives"));
    f.add(Constraint(string("result"), pf_id, "were"));
    f.add(Constraint(string("retractions"), lt_id, (int_t)38));
    f.add(Constraint(string("winders"), eq_id, (int_t)49));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)88));
    f.add(Constraint(string("Finnegan"), eq_id, true));
    f.add(Constraint(string("mature"), eq_id, "multiplicatives"));
    f.add(Constraint(string("result"), pf_id, "were"));
    f.add(Constraint(string("retractions"), lt_id, (int_t)38));
    f.add(Constraint(string("winders"), eq_id, (int_t)49));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), ss_id, "micros"));
    f.add(Constraint(string("aback"), eq_id, (int_t)73));
    f.add(Constraint(string("loner"), eq_id, (int_t)31));
    f.add(Constraint(string("rectangles"), eq_id, 39.1000));
    f.add(Constraint(string("retractions"), lt_id, "segmentation"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), ss_id, "micros"));
    f.add(Constraint(string("aback"), eq_id, (int_t)73));
    f.add(Constraint(string("loner"), eq_id, (int_t)31));
    f.add(Constraint(string("rectangles"), eq_id, 39.1000));
    f.add(Constraint(string("retractions"), lt_id, "segmentation"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)71));
    f.add(Constraint(string("beside"), eq_id, (int_t)68));
    f.add(Constraint(string("centroid"), eq_id, true));
    f.add(Constraint(string("fraternally"), eq_id, (int_t)56));
    f.add(Constraint(string("retractions"), lt_id, 48.1000));
    f.add(Constraint(string("tomography"), eq_id, "picnics"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)71));
    f.add(Constraint(string("beside"), eq_id, (int_t)68));
    f.add(Constraint(string("centroid"), eq_id, true));
    f.add(Constraint(string("fraternally"), eq_id, (int_t)56));
    f.add(Constraint(string("retractions"), lt_id, 48.1000));
    f.add(Constraint(string("tomography"), eq_id, "picnics"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, "inverted"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, "inverted"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, false));
    f.add(Constraint(string("Rawlings"), eq_id, "curries"));
    f.add(Constraint(string("league"), gt_id, "Malawi"));
    f.add(Constraint(string("retractions"), eq_id, (int_t)27));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, false));
    f.add(Constraint(string("Rawlings"), eq_id, "curries"));
    f.add(Constraint(string("league"), gt_id, "Malawi"));
    f.add(Constraint(string("retractions"), eq_id, (int_t)27));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), sf_id, "anonymously"));
    f.add(Constraint(string("Colombians"), eq_id, false));
    f.add(Constraint(string("abuses"), eq_id, "speedboat"));
    f.add(Constraint(string("freight"), eq_id, 90.1000));
    f.add(Constraint(string("tomography"), gt_id, (int_t)87));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), sf_id, "anonymously"));
    f.add(Constraint(string("Colombians"), eq_id, false));
    f.add(Constraint(string("abuses"), eq_id, "speedboat"));
    f.add(Constraint(string("freight"), eq_id, 90.1000));
    f.add(Constraint(string("tomography"), gt_id, (int_t)87));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, 71.1000));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, 71.1000));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, 69.1000));
    f.add(Constraint(string("graces"), eq_id, false));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, 69.1000));
    f.add(Constraint(string("graces"), eq_id, false));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)53));
    f.add(Constraint(string("aback"), pf_id, "motors"));
    f.add(Constraint(string("quadrilateral"), sf_id, "doubtable"));
    f.add(Constraint(string("retractions"), lt_id, (int_t)68));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)53));
    f.add(Constraint(string("aback"), pf_id, "motors"));
    f.add(Constraint(string("quadrilateral"), sf_id, "doubtable"));
    f.add(Constraint(string("retractions"), lt_id, (int_t)68));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, false));
    f.add(Constraint(string("retractions"), eq_id, "relief"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, false));
    f.add(Constraint(string("retractions"), eq_id, "relief"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), ss_id, "micros"));
    f.add(Constraint(string("monolithic"), eq_id, "yearning"));
    f.add(Constraint(string("tomography"), sf_id, "interrelations"));
    f.add(Constraint(string("wallowed"), eq_id, "Creon"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), ss_id, "micros"));
    f.add(Constraint(string("monolithic"), eq_id, "yearning"));
    f.add(Constraint(string("tomography"), sf_id, "interrelations"));
    f.add(Constraint(string("wallowed"), eq_id, "Creon"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, 7.10000));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, 7.10000));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, "procrastinating"));
    f.add(Constraint(string("aback"), eq_id, 27.1000));
    f.add(Constraint(string("pawing"), eq_id, 22.1000));
    f.add(Constraint(string("retractions"), eq_id, true));
    f.add(Constraint(string("tomography"), eq_id, 48.1000));
    f.add(Constraint(string("victimized"), lt_id, (int_t)15));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, "procrastinating"));
    f.add(Constraint(string("aback"), eq_id, 27.1000));
    f.add(Constraint(string("pawing"), eq_id, 22.1000));
    f.add(Constraint(string("retractions"), eq_id, true));
    f.add(Constraint(string("tomography"), eq_id, 48.1000));
    f.add(Constraint(string("victimized"), lt_id, (int_t)15));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "workers"));
    f.add(Constraint(string("Mundt"), eq_id, true));
    f.add(Constraint(string("Susanne"), gt_id, "reddest"));
    f.add(Constraint(string("graces"), eq_id, "awhile"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "workers"));
    f.add(Constraint(string("Mundt"), eq_id, true));
    f.add(Constraint(string("Susanne"), gt_id, "reddest"));
    f.add(Constraint(string("graces"), eq_id, "awhile"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), pf_id, "adducible"));
    f.add(Constraint(string("councilwoman"), lt_id, (int_t)96));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), pf_id, "adducible"));
    f.add(Constraint(string("councilwoman"), lt_id, (int_t)96));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, true));
    f.add(Constraint(string("Colombians"), ss_id, "bottle"));
    f.add(Constraint(string("aback"), eq_id, (int_t)27));
    f.add(Constraint(string("moron"), pf_id, "woolen"));
    f.add(Constraint(string("staples"), gt_id, (int_t)68));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, true));
    f.add(Constraint(string("Colombians"), ss_id, "bottle"));
    f.add(Constraint(string("aback"), eq_id, (int_t)27));
    f.add(Constraint(string("moron"), pf_id, "woolen"));
    f.add(Constraint(string("staples"), gt_id, (int_t)68));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, false));
    f.add(Constraint(string("creeks"), lt_id, 31.1000));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, false));
    f.add(Constraint(string("creeks"), lt_id, 31.1000));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)82));
    f.add(Constraint(string("luscious"), eq_id, false));
    f.add(Constraint(string("tomography"), eq_id, true));
    f.add(Constraint(string("unimaginable"), eq_id, "theatrical"));
    f.add(Constraint(string("whisks"), lt_id, "alienated"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)82));
    f.add(Constraint(string("luscious"), eq_id, false));
    f.add(Constraint(string("tomography"), eq_id, true));
    f.add(Constraint(string("unimaginable"), eq_id, "theatrical"));
    f.add(Constraint(string("whisks"), lt_id, "alienated"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, (int_t)79));
    f.add(Constraint(string("deaden"), eq_id, "Schlitz"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, (int_t)79));
    f.add(Constraint(string("deaden"), eq_id, "Schlitz"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)88));
    f.add(Constraint(string("aback"), eq_id, "antiquarian"));
    f.add(Constraint(string("alternates"), eq_id, false));
    f.add(Constraint(string("baptizing"), eq_id, false));
    f.add(Constraint(string("tomography"), eq_id, (int_t)56));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)88));
    f.add(Constraint(string("aback"), eq_id, "antiquarian"));
    f.add(Constraint(string("alternates"), eq_id, false));
    f.add(Constraint(string("baptizing"), eq_id, false));
    f.add(Constraint(string("tomography"), eq_id, (int_t)56));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)83));
    f.add(Constraint(string("aback"), gt_id, (int_t)76));
    f.add(Constraint(string("appraising"), eq_id, "feigned"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)83));
    f.add(Constraint(string("aback"), gt_id, (int_t)76));
    f.add(Constraint(string("appraising"), eq_id, "feigned"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "hostess"));
    f.add(Constraint(string("alternates"), eq_id, 44.1000));
    f.add(Constraint(string("mergers"), lt_id, (int_t)91));
    f.add(Constraint(string("regrouping"), eq_id, 56.1000));
    f.add(Constraint(string("retractions"), gt_id, "brays"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "hostess"));
    f.add(Constraint(string("alternates"), eq_id, 44.1000));
    f.add(Constraint(string("mergers"), lt_id, (int_t)91));
    f.add(Constraint(string("regrouping"), eq_id, 56.1000));
    f.add(Constraint(string("retractions"), gt_id, "brays"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "northwestern"));
    f.add(Constraint(string("incorrectness"), eq_id, false));
    f.add(Constraint(string("tomography"), sf_id, "veer"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "northwestern"));
    f.add(Constraint(string("incorrectness"), eq_id, false));
    f.add(Constraint(string("tomography"), sf_id, "veer"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, "prostration"));
    f.add(Constraint(string("Fletcher"), ss_id, "detest"));
    f.add(Constraint(string("centralize"), eq_id, 74.1000));
    f.add(Constraint(string("retractions"), eq_id, false));
    f.add(Constraint(string("unchanged"), gt_id, (int_t)14));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, "prostration"));
    f.add(Constraint(string("Fletcher"), ss_id, "detest"));
    f.add(Constraint(string("centralize"), eq_id, 74.1000));
    f.add(Constraint(string("retractions"), eq_id, false));
    f.add(Constraint(string("unchanged"), gt_id, (int_t)14));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)60));
    f.add(Constraint(string("Dominican"), gt_id, (int_t)86));
    f.add(Constraint(string("Palermo"), eq_id, (int_t)6));
    f.add(Constraint(string("aback"), gt_id, (int_t)47));
    f.add(Constraint(string("splintered"), eq_id, (int_t)39));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)60));
    f.add(Constraint(string("Dominican"), gt_id, (int_t)86));
    f.add(Constraint(string("Palermo"), eq_id, (int_t)6));
    f.add(Constraint(string("aback"), gt_id, (int_t)47));
    f.add(Constraint(string("splintered"), eq_id, (int_t)39));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)21));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, (int_t)21));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, (int_t)94));
    f.add(Constraint(string("rectangles"), sf_id, "infests"));
    f.add(Constraint(string("tomography"), lt_id, (int_t)0));
    f.add(Constraint(string("vandalized"), eq_id, (int_t)56));
    f.add(Constraint(string("victimized"), eq_id, "logjam"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, (int_t)94));
    f.add(Constraint(string("rectangles"), sf_id, "infests"));
    f.add(Constraint(string("tomography"), lt_id, (int_t)0));
    f.add(Constraint(string("vandalized"), eq_id, (int_t)56));
    f.add(Constraint(string("victimized"), eq_id, "logjam"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, "hug"));
    f.add(Constraint(string("exiled"), eq_id, true));
    f.add(Constraint(string("misunderstood"), lt_id, (int_t)8));
    f.add(Constraint(string("monolithic"), eq_id, "heatable"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, "hug"));
    f.add(Constraint(string("exiled"), eq_id, true));
    f.add(Constraint(string("misunderstood"), lt_id, (int_t)8));
    f.add(Constraint(string("monolithic"), eq_id, "heatable"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "Smithsonian"));
    f.add(Constraint(string("amasses"), pf_id, "thermostats"));
    f.add(Constraint(string("astride"), eq_id, true));
    f.add(Constraint(string("position"), eq_id, "imposes"));
    f.add(Constraint(string("retractions"), lt_id, (int_t)32));
    f.add(Constraint(string("survival"), eq_id, (int_t)78));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "Smithsonian"));
    f.add(Constraint(string("amasses"), pf_id, "thermostats"));
    f.add(Constraint(string("astride"), eq_id, true));
    f.add(Constraint(string("position"), eq_id, "imposes"));
    f.add(Constraint(string("retractions"), lt_id, (int_t)32));
    f.add(Constraint(string("survival"), eq_id, (int_t)78));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)80));
    f.add(Constraint(string("Colombians"), sf_id, "difficulty"));
    f.add(Constraint(string("retractions"), gt_id, (int_t)69));
    f.add(Constraint(string("seceded"), lt_id, (int_t)9));
    f.add(Constraint(string("squeaked"), gt_id, (int_t)6));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)80));
    f.add(Constraint(string("Colombians"), sf_id, "difficulty"));
    f.add(Constraint(string("retractions"), gt_id, (int_t)69));
    f.add(Constraint(string("seceded"), lt_id, (int_t)9));
    f.add(Constraint(string("squeaked"), gt_id, (int_t)6));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, false));
    f.add(Constraint(string("Laotian"), eq_id, (int_t)98));
    f.add(Constraint(string("consummately"), lt_id, "piecewise"));
    f.add(Constraint(string("cravats"), eq_id, (int_t)88));
    f.add(Constraint(string("retractions"), eq_id, "motors"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, false));
    f.add(Constraint(string("Laotian"), eq_id, (int_t)98));
    f.add(Constraint(string("consummately"), lt_id, "piecewise"));
    f.add(Constraint(string("cravats"), eq_id, (int_t)88));
    f.add(Constraint(string("retractions"), eq_id, "motors"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)76));
    f.add(Constraint(string("aback"), ss_id, "Latinized"));
    f.add(Constraint(string("curtate"), gt_id, 58.1000));
    f.add(Constraint(string("retractions"), eq_id, (int_t)99));
    f.add(Constraint(string("splendid"), eq_id, (int_t)5));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)76));
    f.add(Constraint(string("aback"), ss_id, "Latinized"));
    f.add(Constraint(string("curtate"), gt_id, 58.1000));
    f.add(Constraint(string("retractions"), eq_id, (int_t)99));
    f.add(Constraint(string("splendid"), eq_id, (int_t)5));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), ss_id, "collaborative"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), ss_id, "collaborative"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), pf_id, "awhile"));
    f.add(Constraint(string("callously"), pf_id, "philosophize"));
    f.add(Constraint(string("retractions"), eq_id, "sponge"));
    f.add(Constraint(string("tomography"), eq_id, "caging"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), pf_id, "awhile"));
    f.add(Constraint(string("callously"), pf_id, "philosophize"));
    f.add(Constraint(string("retractions"), eq_id, "sponge"));
    f.add(Constraint(string("tomography"), eq_id, "caging"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), pf_id, "Satanist"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), pf_id, "Satanist"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, (int_t)70));
    f.add(Constraint(string("Budapest"), eq_id, (int_t)6));
    f.add(Constraint(string("graces"), gt_id, (int_t)11));
    f.add(Constraint(string("wield"), eq_id, false));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, (int_t)70));
    f.add(Constraint(string("Budapest"), eq_id, (int_t)6));
    f.add(Constraint(string("graces"), gt_id, (int_t)11));
    f.add(Constraint(string("wield"), eq_id, false));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)39));
    f.add(Constraint(string("moron"), gt_id, "snort"));
    f.add(Constraint(string("steeling"), pf_id, "spawned"));
    f.add(Constraint(string("timidity"), eq_id, "conflagration"));
    f.add(Constraint(string("tomography"), eq_id, (int_t)94));
    f.add(Constraint(string("truncated"), lt_id, "oxides"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)39));
    f.add(Constraint(string("moron"), gt_id, "snort"));
    f.add(Constraint(string("steeling"), pf_id, "spawned"));
    f.add(Constraint(string("timidity"), eq_id, "conflagration"));
    f.add(Constraint(string("tomography"), eq_id, (int_t)94));
    f.add(Constraint(string("truncated"), lt_id, "oxides"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "send"));
    f.add(Constraint(string("astride"), pf_id, "connectors"));
    f.add(Constraint(string("consequent"), eq_id, (int_t)20));
    f.add(Constraint(string("graces"), eq_id, (int_t)66));
    f.add(Constraint(string("observance"), gt_id, "agonizingly"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, "send"));
    f.add(Constraint(string("astride"), pf_id, "connectors"));
    f.add(Constraint(string("consequent"), eq_id, (int_t)20));
    f.add(Constraint(string("graces"), eq_id, (int_t)66));
    f.add(Constraint(string("observance"), gt_id, "agonizingly"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), sf_id, "educations"));
    f.add(Constraint(string("Fletcher"), eq_id, 39.1000));
    f.add(Constraint(string("concrete"), pf_id, "jewelries"));
    f.add(Constraint(string("cremate"), eq_id, (int_t)0));
    f.add(Constraint(string("retractions"), eq_id, (int_t)21));
    f.add(Constraint(string("tomography"), gt_id, (int_t)88));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), sf_id, "educations"));
    f.add(Constraint(string("Fletcher"), eq_id, 39.1000));
    f.add(Constraint(string("concrete"), pf_id, "jewelries"));
    f.add(Constraint(string("cremate"), eq_id, (int_t)0));
    f.add(Constraint(string("retractions"), eq_id, (int_t)21));
    f.add(Constraint(string("tomography"), gt_id, (int_t)88));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), ss_id, "reexamine"));
    f.add(Constraint(string("mergers"), eq_id, "Hunter"));
    f.add(Constraint(string("misunderstood"), ss_id, "Amman"));
    f.add(Constraint(string("quiz"), eq_id, true));
    f.add(Constraint(string("retractions"), eq_id, "bridles"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), ss_id, "reexamine"));
    f.add(Constraint(string("mergers"), eq_id, "Hunter"));
    f.add(Constraint(string("misunderstood"), ss_id, "Amman"));
    f.add(Constraint(string("quiz"), eq_id, true));
    f.add(Constraint(string("retractions"), eq_id, "bridles"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)40));
    f.add(Constraint(string("Buxton"), eq_id, false));
    f.add(Constraint(string("graces"), eq_id, 14.1000));
    f.add(Constraint(string("pedigree"), gt_id, "salvage"));
    f.add(Constraint(string("pilers"), lt_id, (int_t)49));
    f.add(Constraint(string("victimized"), eq_id, true));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)40));
    f.add(Constraint(string("Buxton"), eq_id, false));
    f.add(Constraint(string("graces"), eq_id, 14.1000));
    f.add(Constraint(string("pedigree"), gt_id, "salvage"));
    f.add(Constraint(string("pilers"), lt_id, (int_t)49));
    f.add(Constraint(string("victimized"), eq_id, true));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), gt_id, (int_t)18));
    f.add(Constraint(string("bravo"), eq_id, 47.1000));
    f.add(Constraint(string("fatiguing"), eq_id, (int_t)82));
    f.add(Constraint(string("graces"), sf_id, "transaction"));
    f.add(Constraint(string("spotless"), eq_id, (int_t)38));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), gt_id, (int_t)18));
    f.add(Constraint(string("bravo"), eq_id, 47.1000));
    f.add(Constraint(string("fatiguing"), eq_id, (int_t)82));
    f.add(Constraint(string("graces"), sf_id, "transaction"));
    f.add(Constraint(string("spotless"), eq_id, (int_t)38));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)73));
    f.add(Constraint(string("Riverview"), eq_id, true));
    f.add(Constraint(string("hangover"), gt_id, 62.1000));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)73));
    f.add(Constraint(string("Riverview"), eq_id, true));
    f.add(Constraint(string("hangover"), gt_id, 62.1000));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, true));
    f.add(Constraint(string("Colombians"), lt_id, (int_t)53));
    f.add(Constraint(string("Reuben"), eq_id, "feigned"));
    f.add(Constraint(string("tomography"), eq_id, "transposition"));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, true));
    f.add(Constraint(string("Colombians"), lt_id, (int_t)53));
    f.add(Constraint(string("Reuben"), eq_id, "feigned"));
    f.add(Constraint(string("tomography"), eq_id, "transposition"));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), lt_id, "Travis"));
    f.add(Constraint(string("Palestine"), sf_id, "hitchhikers"));
    f.add(Constraint(string("alternates"), eq_id, (int_t)52));
    f.add(Constraint(string("moron"), lt_id, (int_t)64));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), lt_id, "Travis"));
    f.add(Constraint(string("Palestine"), sf_id, "hitchhikers"));
    f.add(Constraint(string("alternates"), eq_id, (int_t)52));
    f.add(Constraint(string("moron"), lt_id, (int_t)64));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)4));
    f.add(Constraint(string("battalions"), lt_id, "darkly"));
    f.add(Constraint(string("retractions"), gt_id, 91.1000));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)4));
    f.add(Constraint(string("battalions"), lt_id, "darkly"));
    f.add(Constraint(string("retractions"), gt_id, 91.1000));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)96));
    f.add(Constraint(string("beside"), ss_id, "greatly"));
    f.add(Constraint(string("border"), eq_id, (int_t)58));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)96));
    f.add(Constraint(string("beside"), ss_id, "greatly"));
    f.add(Constraint(string("border"), eq_id, (int_t)58));
    bPred.add(f);
  }

  {
    SimplifyingFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)92));
    f.add(Constraint(string("cottonwood"), eq_id, "Thrace"));
    f.add(Constraint(string("mucking"), gt_id, (int_t)97));
    f.add(Constraint(string("oftentimes"), eq_id, "cryptographic"));
    f.add(Constraint(string("retractions"), eq_id, true));
    sPred.add(f);
  }  
  {
    BasicFilter f;
    f.add(Constraint(string("Barhop"), eq_id, (int_t)92));
    f.add(Constraint(string("cottonwood"), eq_id, "Thrace"));
    f.add(Constraint(string("mucking"), gt_id, (int_t)97));
    f.add(Constraint(string("oftentimes"), eq_id, "cryptographic"));
    f.add(Constraint(string("retractions"), eq_id, true));
    bPred.add(f);
  }

  // sorry, have to eyeball it for now
  cout << "Basic Predicate: " << endl;
  bPred.sff(cout);
  cout << endl;
  cout << "Simplified Predicate: " << endl;
  sPred.sff(cout);
  cout << endl;

  return 0;
}
